==> ejc-assistrmat-impl-3.0.0-20220328.104009-23-sources.jar: com/ejianc/business/assist/rmat/service/impl/OrderBpmServiceImpl.java <==
package com.ejianc.business.assist.rmat.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.common.CommonConstant;
import com.ejianc.business.assist.rmat.bean.OrderEntity;
import com.ejianc.business.assist.rmat.bean.StopEntity;
import com.ejianc.business.assist.rmat.enums.SupplierSignStatusEnum;
import com.ejianc.business.assist.rmat.service.IOrderService;
import com.ejianc.business.assist.rmat.utils.MaterialConstant;
import com.ejianc.business.assist.rmat.vo.StopVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("order") 
public class OrderBpmServiceImpl implements ICommonBusinessService {

	private Logger logger = LoggerFactory.getLogger(this.getClass());

	@Autowired
	private IBillTypeApi billTypeApi;

	@Autowired
	private IOrderService service;

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		OrderEntity entity = service.selectById(billId);
		entity.setReceiveState(CommonConstant.ORDER_RECEIVE_WAIT);

		//单据协同推送
		boolean pushResult = service.pushBillToSupCenter(entity);
		if(!pushResult) {
			return CommonResponse.error("审批回调失败，单据推送协同服务失败！");
		}

		//修改订单接收状态为待接收
		LambdaUpdateWrapper<OrderEntity> updateWrapper = new LambdaUpdateWrapper();
		updateWrapper.eq(OrderEntity::getId,billId);
		updateWrapper.set(OrderEntity::getReceiveState,CommonConstant.ORDER_RECEIVE_WAIT);
		service.update(updateWrapper);

		return CommonResponse.success("审批回调成功！");
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		OrderEntity entity = service.selectById(billId);

		//检测单据是否供应商接收
		if(!CommonConstant.ORDER_RECEIVE_WAIT.equals(entity.getReceiveState())) {
			return CommonResponse.error("供应商已接收，无法执行此操作！");
		}

		// 是否被其他单据引用
		CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
		logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
		if(!res.isSuccess()) {//单据未被下游单据引用
			return CommonResponse.error(res.getMsg());
		}

		//将推送至供方的单据作废
		boolean pushResult = service.delPushBill(entity);
		if (!pushResult) {
			return CommonResponse.error("弃审前回调失败，单据作废协同服务失败！");
		}

		//修改订单接收状态为空
		LambdaUpdateWrapper<OrderEntity> updateWrapper = new LambdaUpdateWrapper();
		updateWrapper.eq(OrderEntity::getId,billId);
		updateWrapper.set(OrderEntity::getReceiveState,null);
		service.update(updateWrapper);

		return CommonResponse.success("弃审前回调成功！");
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> ejc-assistrmat-impl-3.0.0-20220331.102047-32-sources.jar: com/ejianc/business/assist/rmat/service/impl/OrderBpmServiceImpl.java <==
package com.ejianc.business.assist.rmat.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.assist.rmat.enums.BillPushStatusEnum;
import com.ejianc.business.assist.rmat.enums.BillTypeEnum;
import com.ejianc.business.common.CommonConstant;
import com.ejianc.business.assist.rmat.bean.OrderEntity;
import com.ejianc.business.assist.rmat.bean.StopEntity;
import com.ejianc.business.assist.rmat.enums.SupplierSignStatusEnum;
import com.ejianc.business.assist.rmat.service.IOrderService;
import com.ejianc.business.assist.rmat.utils.MaterialConstant;
import com.ejianc.business.assist.rmat.vo.StopVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("order") 
public class OrderBpmServiceImpl implements ICommonBusinessService {

	private Logger logger = LoggerFactory.getLogger(this.getClass());

	@Autowired
	private IBillTypeApi billTypeApi;

	@Autowired
	private IOrderService service;

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		OrderEntity entity = service.selectById(billId);
		entity.setReceiveState(CommonConstant.ORDER_RECEIVE_WAIT);

		//单据协同推送
		boolean pushResult = service.pushBillToSupCenter(entity);
		if(!pushResult) {
			return CommonResponse.error("审批回调失败，单据推送协同服务失败！");
		}else {
			logger.error("单据-{}id-{}推送供应商服务失败", BillTypeEnum.租赁订单.getName(), billId);
			entity.setBillPushFlag(BillPushStatusEnum.未成功推送.getStatus());
		}

		//修改订单接收状态为待接收
		LambdaUpdateWrapper<OrderEntity> updateWrapper = new LambdaUpdateWrapper();
		updateWrapper.eq(OrderEntity::getId,billId);
		updateWrapper.set(OrderEntity::getReceiveState,CommonConstant.ORDER_RECEIVE_WAIT);
		service.update(updateWrapper);

		return CommonResponse.success("审批回调成功！");
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		OrderEntity entity = service.selectById(billId);

		//检测单据是否供应商接收
		if(!CommonConstant.ORDER_RECEIVE_WAIT.equals(entity.getReceiveState())) {
			return CommonResponse.error("供应商已接收，无法执行此操作！");
		}

		// 是否被其他单据引用
		CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
		logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
		if(!res.isSuccess()) {//单据未被下游单据引用
			return CommonResponse.error(res.getMsg());
		}

		//将推送至供方的单据作废
		boolean pushResult = service.delPushBill(entity);
		if (!pushResult) {
			return CommonResponse.error("弃审前回调失败，单据作废协同服务失败！");
		}

		//修改订单接收状态为空
		LambdaUpdateWrapper<OrderEntity> updateWrapper = new LambdaUpdateWrapper();
		updateWrapper.eq(OrderEntity::getId,billId);
		updateWrapper.set(OrderEntity::getReceiveState,null);
		service.update(updateWrapper);

		return CommonResponse.success("弃审前回调成功！");
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}
